@@ -6,6 +6,7 @@
 # Description:
 import re
 import time
+import logging
 import jionlp as jio
 from math import ceil
 from datetime import datetime
@@ -53,8 +54,8 @@ def get_time(text: str, tend_future=True, time_base=None):
         if isinstance(t2, datetime):
             t2 = t2.strftime(TIME_FORMAT)
         time_tuple = (t1, t2)
-    except ValueError as _:
-        pass
+    except Exception as e:
+        logging.error(f"nlp-time get_time error {e} of text {text}")
     return time_text, time_tuple
 
 
